### Eclipse Workspace Patch 1.0
#P simpletest
Index: tests/functional/node.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/node.test,v
retrieving revision 1.7
diff -u -r1.7 node.test
--- tests/functional/node.test	23 Mar 2008 03:42:16 -0000	1.7
+++ tests/functional/node.test	23 Mar 2008 03:49:38 -0000
@@ -3,9 +3,9 @@
 
 class NodeRevisionsTest extends DrupalTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Node revisions tests'),
       'description' => t('Creates a node of type page and then a user tries various revision actions such as viewing, reverting to, and deleting revisions.'),
@@ -112,9 +112,9 @@
 
 class NodeTeaserTest extends DrupalTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Node teaser tests'),
       'description' => t('Calls node_teaser() with different strings and lengths.'),
@@ -263,7 +263,7 @@
 }
 
 class StoryEditTest extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array(
       'name'  => 'Story edit test',
       'description'  => t('We want a working edit for storys, uh?'),
@@ -312,7 +312,7 @@
 }
 
 class StoryPreviewTest extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array(
    'name'  => 'Story preview test',
    'description'  => t('We want a working preview for storys, uh?'),
@@ -345,9 +345,9 @@
 class PageCreationTest extends  DrupalTestCase {
 
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Page node creation'),
       'description' => t('Create a page node and verify its consistency in the database.'),
@@ -378,9 +378,9 @@
 
 class PageViewTest extends DrupalTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Unauthorized node view'),
       'description' => t('Creates a node of type page and then an unpermissioned user attempts to edit the node, '
Index: tests/functional/comment.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/comment.test,v
retrieving revision 1.7
diff -u -r1.7 comment.test
--- tests/functional/comment.test	22 Mar 2008 02:50:06 -0000	1.7
+++ tests/functional/comment.test	23 Mar 2008 03:49:37 -0000
@@ -7,9 +7,9 @@
   var $node;
 
   /**
-   * Implementation of get_info().
+   * Implementation of getInfo().
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Comment functionality'),
       'description' => t('Thoroughly test comment administration and user interfaces.'),
Index: tests/functional/book.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/book.test,v
retrieving revision 1.5
diff -u -r1.5 book.test
--- tests/functional/book.test	23 Mar 2008 03:42:16 -0000	1.5
+++ tests/functional/book.test	23 Mar 2008 03:49:37 -0000
@@ -4,7 +4,7 @@
 class BookModuleTestCase extends DrupalTestCase {
   protected $book;
 
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Book functionality'),
       'description' => t('Create a book, add pages, and test book interface.'),
Index: tests/functional/menu.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/menu.test,v
retrieving revision 1.5
diff -u -r1.5 menu.test
--- tests/functional/menu.test	23 Mar 2008 03:42:16 -0000	1.5
+++ tests/functional/menu.test	23 Mar 2008 03:49:38 -0000
@@ -4,9 +4,9 @@
 class MenuModuleTestCase extends  DrupalTestCase {
 
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Menu link creation/deletion'),
       'description' => t('Create two links in the Navigation menu, check their data, and delete them using the menu module UI.'),
@@ -84,9 +84,9 @@
 class MenuModuleCustomMenuTest extends MenuModuleTestCase {
 
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Custom menu creation/deletion'),
       'description' => t('Create a custom menu, add a link to it, and delete it using the menu module UI.'),
@@ -135,9 +135,9 @@
 
 class MenuModuleEnable extends DrupalTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Menu enable'),
       'description' => 'Enable / disable a menu item',
@@ -179,9 +179,9 @@
 
 class MenuModuleReset extends DrupalTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Menu reset'),
       'description' => 'Edit and reset a menu item',
@@ -240,9 +240,9 @@
 
 class MenuModuleInvalidPath extends DrupalTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Menu invalid path'),
       'description' => 'Try to create a menu item with an invalid / inaccesible path.',
Index: tests/functional/translation.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/translation.test,v
retrieving revision 1.6
diff -u -r1.6 translation.test
--- tests/functional/translation.test	23 Mar 2008 03:42:16 -0000	1.6
+++ tests/functional/translation.test	23 Mar 2008 03:49:40 -0000
@@ -4,7 +4,7 @@
 class TranslationModuleTestCase extends DrupalTestCase {
   var $book;
 
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Translation functionality'),
       'description' => t('Create a story with translation, modify the story outdating translation, and update translation.'),
Index: tests/functional/forum.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/forum.test,v
retrieving revision 1.7
diff -u -r1.7 forum.test
--- tests/functional/forum.test	23 Mar 2008 03:42:16 -0000	1.7
+++ tests/functional/forum.test	23 Mar 2008 03:49:38 -0000
@@ -3,9 +3,9 @@
 
 class DrupalForumTestCase extends DrupalTestCase {
   /**
-  * Implementation of get_info() for information
+  * Implementation of getInfo() for information
   */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Forum test functions'), 'description' => 'Helps the forum test cases run by providing common functions. Does not need to be checked.', 'group' => 'Forum');
   }
 
@@ -73,9 +73,9 @@
 
 class AddForumTest extends DrupalForumTestCase {
   /**
-  * Implementation of get_info() for information
+  * Implementation of getInfo() for information
   */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Add forum'), 'description' => 'Adds a forum and a forum container and verifies that they have been created.', 'group' => 'Forum');
   }
 
@@ -114,9 +114,9 @@
 
 class EditForumTaxonomyTest extends DrupalForumTestCase {
   /**
-  * Implementation of get_info() for information
+  * Implementation of getInfo() for information
   */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Edit forum taxonomy'), 'description' => 'Edits the forum taxonomy.', 'group' => 'Forum');
   }
 
@@ -163,9 +163,9 @@
 
 class AddTopicToForum extends DrupalForumTestCase {
   /**
-  * Implementation of get_info() for information
+  * Implementation of getInfo() for information
   */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Add/move topics'), 'description' => 'Tests adding and moving topics within forums.', 'group' => 'Forum');
   }
 
Index: tests/functional/aggregator.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/aggregator.test,v
retrieving revision 1.4
diff -u -r1.4 aggregator.test
--- tests/functional/aggregator.test	23 Mar 2008 03:42:16 -0000	1.4
+++ tests/functional/aggregator.test	23 Mar 2008 03:49:37 -0000
@@ -98,9 +98,9 @@
 
 class AddFeedTestCase extends DrupalAggregatorTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Aggregator Add Feed functionality'),
       'description' => t('Add feed test.'),
       'group' => t('Feed Tests'),);
@@ -120,9 +120,9 @@
 
 class UpdateFeedTestCase extends DrupalAggregatorTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Aggregator Update Feed functionality'),
       'description' => t('Update feed test.'),
       'group' => t('Feed Tests'),);
@@ -146,9 +146,9 @@
 
 class RemoveFeedTestCase extends DrupalAggregatorTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Aggregator Remove Feed functionality'),
       'description' => t('Remove feed test.'),
       'group' => t('Feed Tests'),);
@@ -167,9 +167,9 @@
 
 class UpdateFeedItemTestCase extends DrupalAggregatorTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Aggregator Update Feed Item functionality'),
       'description' => t('Update feed items from a feed.'),
       'group' => t('Feed Tests'),);
@@ -191,9 +191,9 @@
 
 class RemoveFeedItemTestCase extends DrupalAggregatorTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Aggregator Remove Feed Item functionality'),
       'description' => t('Remove feed items from a feed.'),
       'group' => t('Feed Tests'),);
@@ -214,9 +214,9 @@
 
 class CategorizeFeedItemTestCase extends DrupalAggregatorTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Aggregator Categorize Feed Item functionality'),
       'description' => t('Test feed item categorization.'),
       'group' => t('Feed Tests'),);
Index: tests/functional/contact.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/contact.test,v
retrieving revision 1.5
diff -u -r1.5 contact.test
--- tests/functional/contact.test	22 Mar 2008 02:50:06 -0000	1.5
+++ tests/functional/contact.test	23 Mar 2008 03:49:38 -0000
@@ -2,7 +2,7 @@
 // $Id: contact.test,v 1.5 2008/03/22 02:50:06 boombatower Exp $
 
 class ContactModuleTestCase extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Contact functionality'),
       'description' => t('Test site-wide contact form and personal contact form functionality.'),
Index: tests/functional/system.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/system.test,v
retrieving revision 1.6
diff -u -r1.6 system.test
--- tests/functional/system.test	22 Mar 2008 02:50:06 -0000	1.6
+++ tests/functional/system.test	23 Mar 2008 03:49:39 -0000
@@ -3,9 +3,9 @@
 
 class EnableCoreModuleTest extends DrupalTestCase {
   /**
-  * Implementation of get_info() for information
+  * Implementation of getInfo() for information
   */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Enable core modules'), 'description' => 'Enables all core modules by POST - looks for error messages, confirms table creation, etc.', 'group' => 'Modules');
   }
 
@@ -95,9 +95,9 @@
 
 class EnableModuleWithoutDependencyTest extends DrupalTestCase {
   /**
-  * Implementation of get_info() for information
+  * Implementation of getInfo() for information
   */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Enable module without required dependencies'), 'description' => 'Attempts to enable the forum module without enabling dependencies.', 'group' => 'Modules');
   }
 
@@ -130,9 +130,9 @@
 
 class DisableUninstallCoreModuleTest extends DrupalTestCase {
   /**
-  * Implementation of get_info() for information
+  * Implementation of getInfo() for information
   */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Disable/uninstall core modules'), 'description' => 'Disables and uninstalls core modules, ensures that that tables are properly deleted, no error messages are shown, etc.', 'group' => 'Modules');
   }
 
Index: tests/functional/poll.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/poll.test,v
retrieving revision 1.6
diff -u -r1.6 poll.test
--- tests/functional/poll.test	22 Mar 2008 02:50:06 -0000	1.6
+++ tests/functional/poll.test	23 Mar 2008 03:49:38 -0000
@@ -44,9 +44,9 @@
 class PollCreateTest extends PollTests {
 
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Poll create'), 'description' => 'Adds "more choices", previews and creates a poll.', 'group' => 'Poll module tests');
   }
 
@@ -62,9 +62,9 @@
 
 class PollVoteTest extends PollTests {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array('name' => t('Poll vote'), 'description' => 'Vote on a poll', 'group' => 'Poll module tests');
   }
 
Index: tests/functional/search.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/search.test,v
retrieving revision 1.4
diff -u -r1.4 search.test
--- tests/functional/search.test	23 Mar 2008 03:42:16 -0000	1.4
+++ tests/functional/search.test	23 Mar 2008 03:49:39 -0000
@@ -5,7 +5,7 @@
 
 class SearchMatchTest extends DrupalTestCase {
 
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Search engine queries'),
       'description' => t('Indexes content and queries it.'),
Index: tests/functional/upload.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/upload.test,v
retrieving revision 1.8
diff -u -r1.8 upload.test
--- tests/functional/upload.test	23 Mar 2008 03:42:16 -0000	1.8
+++ tests/functional/upload.test	23 Mar 2008 03:49:40 -0000
@@ -3,9 +3,9 @@
 
 class upload_module_test_case extends DrupalTestCase {
   /**
-   * Implementation of get_info().
+   * Implementation of getInfo().
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Upload functionality'),
       'description' => t('Check content uploaded to nodes.'),
@@ -118,7 +118,7 @@
 }
 
 class UploadPictureTests extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => 'Upload user picture',
       'description' => 'Assure that dimension check, extension check and image scaling work as designed.',
@@ -191,7 +191,7 @@
         $old_dim = variable_get('user_picture_dimensions', '85x85');
         $old_size = variable_get('user_picture_file_size', '30');
         $img_path = realpath("modules/tests/pictureTesting.jpg");
-        $info = image_get_info($img_path);
+        $info = image_getInfo($img_path);
 
         // set new variables;
         $test_size = floor(filesize($img_path) / 1000) + 1;
@@ -247,7 +247,7 @@
         $old_dim = variable_get('user_picture_dimensions', '85x85');
         $old_size = variable_get('user_picture_file_size', '30');
         $img_path = realpath("modules/tests/pictureTesting.jpg");
-        $info = image_get_info($img_path);
+        $info = image_getInfo($img_path);
         // set new variables;
 
         $test_dim = ($info['width'] + 10) . 'x' . ($info['height'] + 10);
@@ -301,7 +301,7 @@
         $old_dim = variable_get('user_picture_dimensions', '85x85');
         $old_size = variable_get('user_picture_file_size', '30');
         $img_path = realpath("modules/tests/pictureTesting.jpg");
-        $info = image_get_info($img_path);
+        $info = image_getInfo($img_path);
         // set new variables;
         $test_size = floor(filesize($img_path) / 1000) + 1;
         $test_dim = ($info['width'] - 10) . 'x' . ($info['height'] - 10);
@@ -350,7 +350,7 @@
         $old_dim = variable_get('user_picture_dimensions', '85x85');
         $old_size = variable_get('user_picture_file_size', '30');
         $img_path = realpath("modules/tests/pictureTesting.jpg");
-        $info = image_get_info($img_path);
+        $info = image_getInfo($img_path);
         // invalid size
         // restore one and set another
         $test_dim = ($info['width'] + 10) . 'x' . ($info['height'] + 10);
@@ -396,7 +396,7 @@
       $old_dim = variable_get('user_picture_dimensions', '85x85');
       $old_size = variable_get('user_picture_file_size', '30');
       $img_path = realpath(drupal_get_path('module', 'simpletest'). "/tests/pictureTesting.jpg");
-      $info = image_get_info($img_path);
+      $info = image_getInfo($img_path);
 
       // valid size & dimensions
       // restore one and set another
Index: tests/functional/trigger.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/trigger.test,v
retrieving revision 1.6
diff -u -r1.6 trigger.test
--- tests/functional/trigger.test	23 Mar 2008 03:42:16 -0000	1.6
+++ tests/functional/trigger.test	23 Mar 2008 03:49:40 -0000
@@ -6,9 +6,9 @@
   var $_cleanup_users = array();
 
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Actions content'),
       'description' => t('Perform various tests with content actions.') ,
Index: tests/functional/user.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/user.test,v
retrieving revision 1.6
diff -u -r1.6 user.test
--- tests/functional/user.test	22 Mar 2008 02:50:06 -0000	1.6
+++ tests/functional/user.test	23 Mar 2008 03:49:40 -0000
@@ -6,7 +6,7 @@
  * - based on initial version by Kuba Zygmunt -
  */
 class UserRegistrationTest extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array('name' => t('User registration'), 'description' => t('Registers a user, fails login, resets password, successfully logs in with the one time password, changes password, logs out, successfully logs in with the new password, visits profile page.') , 'group' => 'User tests');
   }
 
@@ -112,7 +112,7 @@
  * This class is based on the original Simpletest Module by Moshe Weitzman
  */
 class UserValidationTest extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array('name' => 'Username/email validation', 'description' => 'Verify that username/email validity checks behave as designed.' , 'group' => 'User tests');
   }
 
@@ -159,7 +159,7 @@
 class UserAccessTest extends DrupalTestCase {
   var $_cleanup_masks = array();
 
-  function get_info() {
+  function getInfo() {
     return array('name' => t('User access rules'),
                  'description' => t('Assure that negative and positive access rules behave as designed.') ,
                  'group' => 'User tests'
@@ -226,7 +226,7 @@
 }
 
 class UserDeleteTest extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array('name' => t('User delete'), 'description' => t('Registers a user and deletes it.') , 'group' => 'User tests');
   }
 
Index: tests/functional/block.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/block.test,v
retrieving revision 1.5
diff -u -r1.5 block.test
--- tests/functional/block.test	22 Mar 2008 02:50:06 -0000	1.5
+++ tests/functional/block.test	23 Mar 2008 03:49:37 -0000
@@ -2,7 +2,7 @@
 // $Id: block.test,v 1.5 2008/03/22 02:50:06 boombatower Exp $
 
 class BlockModuleTestCase extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Block functionality'),
       'description' => t('Add, edit and delete custom block. Configure and move a module-defined block.'),
Index: tests/functional/taxonomy.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/taxonomy.test,v
retrieving revision 1.6
diff -u -r1.6 taxonomy.test
--- tests/functional/taxonomy.test	22 Mar 2008 02:50:06 -0000	1.6
+++ tests/functional/taxonomy.test	23 Mar 2008 03:49:39 -0000
@@ -2,7 +2,7 @@
 // $Id: taxonomy.test,v 1.6 2008/03/22 02:50:06 boombatower Exp $
 
 class TaxonomyVocabularyFunctions extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array('name' => 'Vocabulary functions', 'description' => "Create/Edit/Delete a vocabulary and assert that all fields were properly saved" , 'group' => 'Taxonomy');
   }
 
@@ -74,7 +74,7 @@
 
 
 class TaxonomyTermFunctions extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array('name' => 'Term functions', 'description' => "Testing save/update/delete terms" , 'group' => 'Taxonomy');
   }
 
@@ -235,7 +235,7 @@
 }
 
 class TaxonomyTestNodeApi extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array('name' => 'Taxonomy nodeapi', 'description' => "Save & edit a node and assert that taxonomy terms are saved/loaded properly." , 'group' => 'Taxonomy');
   }
 
Index: tests/functional/filter.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/filter.test,v
retrieving revision 1.5
diff -u -r1.5 filter.test
--- tests/functional/filter.test	23 Mar 2008 03:42:16 -0000	1.5
+++ tests/functional/filter.test	23 Mar 2008 03:49:38 -0000
@@ -2,7 +2,7 @@
 // $Id: filter.test,v 1.5 2008/03/23 03:42:16 boombatower Exp $
 
 class FilterModuleTestCase extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Filter administration functionality'),
       'description' => t('Thoroughly test the administrative interface of the filter module.'),
Index: tests/functional/blogapi.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/blogapi.test,v
retrieving revision 1.5
diff -u -r1.5 blogapi.test
--- tests/functional/blogapi.test	23 Mar 2008 03:42:16 -0000	1.5
+++ tests/functional/blogapi.test	23 Mar 2008 03:49:37 -0000
@@ -2,7 +2,7 @@
 // $Id: blogapi.test,v 1.5 2008/03/23 03:42:16 boombatower Exp $
 
 class BlogAPIModuleTestCase extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('BlogAPI functionality'),
       'description' => t('Create, edit, and delete post; upload file; and set/get categories.'),
Index: tests/functional/path.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/path.test,v
retrieving revision 1.6
diff -u -r1.6 path.test
--- tests/functional/path.test	22 Mar 2008 02:50:06 -0000	1.6
+++ tests/functional/path.test	23 Mar 2008 03:49:38 -0000
@@ -2,7 +2,7 @@
 // $Id: path.test,v 1.6 2008/03/22 02:50:06 boombatower Exp $
 
 class PathModuleTestCase extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('Path alias functionality'),
       'description' => t('Add, edit, delete, and change alias and verify its consistency in the database.'),
Index: tests/functional/profile.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/profile.test,v
retrieving revision 1.5
diff -u -r1.5 profile.test
--- tests/functional/profile.test	22 Mar 2008 01:19:17 -0000	1.5
+++ tests/functional/profile.test	23 Mar 2008 03:49:39 -0000
@@ -2,7 +2,7 @@
 // $Id: profile.test,v 1.5 2008/03/22 01:19:17 boombatower Exp $
 
 class ProfileModuleTestSingle extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     $modules = (module_list());
     return array('name' => 'Test Single field', 'description' => "Testing profile module with add/edit/delete new fields into profile page" , 'group' => 'Profile Module');
   }
@@ -120,7 +120,7 @@
 }
 
 class ProfileModuleTestTextarea extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     $modules = (module_list());
     return array('name' => 'Test Textarea field', 'description' => "Testing profile module with add/edit/delete new fields into profile page" , 'group' => 'Profile Module');
   }
@@ -234,7 +234,7 @@
 
 
 class ProfileModuleTestFreelist extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     $modules = (module_list());
     return array('name' => 'Test Freelist field', 'description' => "Testing profile module with add/edit/delete new fields into profile page" , 'group' => 'Profile Module');
   }
@@ -349,7 +349,7 @@
 
 
 class ProfileModuleTestCheckbox extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     $modules = (module_list());
     return array('name' => 'Test Checkbox field', 'description' => "Testing profile module with add/edit/delete new fields into profile page" , 'group' => 'Profile Module');
   }
@@ -461,7 +461,7 @@
 }
 
 class ProfileModuleTestUrl extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     $modules = (module_list());
     return array('name' => 'Test Url field', 'description' => "Testing profile module with add/edit/delete new fields into profile page" , 'group' => 'Profile Module');
   }
@@ -576,7 +576,7 @@
 }
 
 class ProfileModuleTestSelection extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     $modules = (module_list());
     return array('name' => 'Test Selection field', 'description' => "Testing profile module with add/edit/delete new fields into profile page" , 'group' => 'Profile Module');
   }
@@ -701,7 +701,7 @@
 
 
 class ProfileModuleTestDate extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     $modules = (module_list());
     return array('name' => 'Test Date field', 'description' => "Testing profile module with add/edit/delete new fields into profile page" , 'group' => 'Profile Module');
   }
@@ -830,7 +830,7 @@
 
 
 class ProfileModuleTest2 extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     $modules = (module_list());
     return array('name' => 'Test other fields', 'description' => "Testing weight, title page, required" , 'group' => 'Profile Module');
   }
Index: tests/functional/locale.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/functional/locale.test,v
retrieving revision 1.6
diff -u -r1.6 locale.test
--- tests/functional/locale.test	23 Mar 2008 03:42:16 -0000	1.6
+++ tests/functional/locale.test	23 Mar 2008 03:49:38 -0000
@@ -3,9 +3,9 @@
 
 class LocaleModuleTest extends DrupalTestCase {
   /**
-   * Implementation of get_info() for information
+   * Implementation of getInfo() for information
    */
-  function get_info() {
+  function getInfo() {
     return array(
       'name' => t('String translate'),
       'description' => 'Adds a new locale and translates its name',
Index: tests/unit/xmlrpc.inc.test
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/tests/unit/xmlrpc.inc.test,v
retrieving revision 1.3
diff -u -r1.3 xmlrpc.inc.test
--- tests/unit/xmlrpc.inc.test	23 Mar 2008 03:42:17 -0000	1.3
+++ tests/unit/xmlrpc.inc.test	23 Mar 2008 03:49:40 -0000
@@ -2,7 +2,7 @@
 // $Id: xmlrpc.inc.test,v 1.3 2008/03/23 03:42:17 boombatower Exp $
 
 class XMLRPCValidator1Test extends DrupalTestCase {
-  function get_info() {
+  function getInfo() {
     return array('name'  => 'XML-RPC validator1',
                  'description'  => t('See !validator-link. note: simpletest_xmlrpc.module must be enabled', array('!validator-link' => l('the xmlrpc validator1 specification', 'http://www.xmlrpc.com/validator1Docs'))),
                  'group' => 'XML-RPC Tests');
Index: simpletest.module
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/simpletest.module,v
retrieving revision 1.37
diff -u -r1.37 simpletest.module
--- simpletest.module	23 Mar 2008 03:35:38 -0000	1.37
+++ simpletest.module	23 Mar 2008 03:49:37 -0000
@@ -161,7 +161,7 @@
       '#attributes' => array('class' => $group_class),
     );
     foreach ($tests as $test) {
-      $test_info = $test->get_info();
+      $test_info = $test->getInfo();
       $group['tests'][get_class($test)] = array(
         '#type' => 'checkbox',
         '#title' => $test_info['name'],
Index: drupal_test_case.php
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/drupal_test_case.php,v
retrieving revision 1.63
diff -u -r1.63 drupal_test_case.php
--- drupal_test_case.php	23 Mar 2008 03:35:38 -0000	1.63
+++ drupal_test_case.php	23 Mar 2008 03:49:37 -0000
@@ -25,8 +25,8 @@
 
   function __construct($label = NULL) {
     if (!$label) {
-      if (method_exists($this, 'get_info')) {
-        $info  = $this->get_info();
+      if (method_exists($this, 'getInfo')) {
+        $info  = $this->getInfo();
         $label = $info['name'];
       }
     }
@@ -430,8 +430,8 @@
    */
   function run(&$reporter) {
     $arr = array('class' => get_class($this));
-    if (method_exists($this, 'get_info')) {
-      $arr = array_merge($arr, $this->get_info());
+    if (method_exists($this, 'getInfo')) {
+      $arr = array_merge($arr, $this->getInfo());
     }
     $reporter->test_info_stack[] = $arr;
     parent::run($reporter);

Index: drupal_unit_tests.php
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/simpletest/drupal_unit_tests.php,v
retrieving revision 1.14
diff -u -r1.14 drupal_unit_tests.php
--- drupal_unit_tests.php	23 Mar 2008 03:35:38 -0000	1.14
+++ drupal_unit_tests.php	23 Mar 2008 03:49:37 -0000
@@ -79,14 +79,14 @@
   }
 
   /**
    * Adds a class to a groups array specified by the get_info of the group
    * @param array  $groups Group of categorized tests
    * @param string $class  Name of a class
    */
   function _addClassToGroups(&$groups, $class) {
     $test = &new $class();
-    if (method_exists($test, 'get_info')) {
-      $info = $test->get_info();
+    if (method_exists($test, 'getInfo')) {
+      $info = $test->getInfo();
       $groups[$info['group']][] = $test;
     }
   }
@@ -79,14 +79,14 @@
 
   /**
-   * Adds a class to a groups array specified by the get_info of the group
+   * Adds a class to a groups array specified by the getInfo of the group
    * @param array  $groups Group of categorized tests
    * @param string $class  Name of a class